@@ -1,5 +1,5 @@
 /*  Motti -- a strategy game
-    Copyright (C) 1999-2010 Free Software Foundation
+    Copyright (C) 1999-2014 Free Software Foundation
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 #include "GameManager.h"
 #include "StringDrawer.h"
 #include "MapGenerator.h"
+#include "ConfigCentral.h"
+#include <fstream>
 #ifndef WIN32
 #include <time.h>
 #include "config.h"
@@ -61,11 +63,18 @@ mess+="\nUsage: /bin/motti \n";
 mess+="Mandatory arguments to long options are mandatory for short options too. \n";
 mess+="      -h --help     display this help and exit \n";
 mess+="      -v --version  output version information and exit \n";
+mess+="      -a --action  play in command line and exit \n";
+mess+="      -s --session  play in command line and exit \n";
+mess+="      -f --action-file  action file (json based) in command line and exit \n";
+mess+="      -p --path  game path  in command line and exit \n";
 mess+="\n\nExit status is 0 if OK, 1 if minor problems, 2 if serious trouble.\n";
 mess+="\nReport bugs to http://savannah.gnu.org/projects/motti.\n";
 	return mess;
 }
-
+#include <ctype.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
 void verifyVersionHelp(int argc, char *argv[]){
 	int i=0;
 	for (i=0;i<argc;i++)
@@ -83,6 +92,68 @@ void verifyVersionHelp(int argc, char *argv[]){
 			exit(0);
 		}
 	}
+	int aflag = 0;
+       int bflag = 0;
+       char *action = NULL;
+       char *path = NULL;
+       char *session = NULL;
+       char *actionfile = NULL;
+       int index;
+       int c;
+	while ((c = getopt (argc, argv, "a:p:s:f:")) != -1)
+         switch (c)
+           {
+           case 'a':
+             action = optarg;
+             break;
+           case 'p':
+             path = optarg;
+             break;
+	   case 's':
+             session = optarg;
+             break;
+           case 'f':
+             actionfile = optarg;
+             break;
+           default:
+             break;
+           }
+           if (path != NULL)
+	   {
+	     ConfigCentral::setGamePath(path);
+	  }
+	    
+           if (action != NULL)
+	   {
+	      std::string stsession="";
+	      if (session!=NULL)
+		  stsession=session;
+	      std::string staction="";
+	      if (action!=NULL)
+		  staction=action;
+	      std::string filein="";
+	      if (actionfile!=NULL)
+	      {
+		std::ifstream ifs(actionfile);
+		filein=std::string((std::istreambuf_iterator<char>(ifs)), std::istreambuf_iterator<char>());
+		ifs.close();
+	      }
+	      //std::cout<<"session:"<<stsession<<std::endl;
+	      //std::cout<<"action:"<<staction<<std::endl;
+	      //std::cout<<"filein:"<<filein<<std::endl;
+	      try{
+		std::string mess=GameDispatcher::dispatch(stsession,staction,filein);
+		std::cout<<mess<<std::endl;
+	      }catch (std::string err)
+	      {
+		std::cout<<err<<std::endl;
+	      }
+	      catch (std::string *err)
+	      {
+		std::cout<<*err<<std::endl;
+	      }
+	      exit(0);
+	   }
 }
 
 
